operators
=========
.. automodule:: tike.operators
   :members:
   :undoc-members:

   .. autosummary::
      Operator
      Alignment
      Bucket
      CachedFFT
      Convolution
      Flow
      Lamino
      Pad
      Patch
      Propagation
      Ptycho
      Rotate
      Shift

.. autoclass:: Alignment
.. autoclass:: Bucket
.. autoclass:: CachedFFT
.. autoclass:: Convolution
.. autoclass:: Flow
.. autoclass:: Lamino
.. autoclass:: Operator
.. autoclass:: Pad
.. autoclass:: Patch
.. autoclass:: Propagation
.. autoclass:: Ptycho
.. autoclass:: Rotate
.. autoclass:: Shift

.. autofunction:: gaussian
.. autofunction:: gaussian_each_pattern
.. autofunction:: gaussian_grad
.. autofunction:: poisson
.. autofunction:: poisson_each_pattern
.. autofunction:: poisson_grad
